from apella.models import (
    MCAInstitutionPositions, MinistryCouncilAct, Institution)
from apella.management.utils import LoadDataCommand


class Command(LoadDataCommand):

    MODEL = MCAInstitutionPositions
    success = 0
    failed = 0

    def add_arguments(self, parser):
        parser.add_argument('--dry-run', dest='dry_run')
        super(Command, self).add_arguments(parser)

    def check_attr_is_int(self, attr, attr_name):
        try:
            int(attr)
        except ValueError:
            self.stdout.write(
                '----- Could not parse %s "%s"' % (attr_name, attr)
            )
            self.failed += 1

    def check_attr_is_id(self, attr, attr_name, model):
        self.check_attr_is_int(attr, attr_name)
        try:
            return model.objects.get(id=attr)
        except model.DoesNotExist:
            self.stdout.write(
                '----- Could not find object with %s: %s' % (attr_name, attr)
            )
            self.failed += 1
            return None

    def handle(self, *args, **options):
        file_path = options['csv_file']
        dry_run = options['dry_run']

        with open(file_path) as csv_file:
            for entry in csv_file:
                mca_id, institution_id, positions = self.preprocess(entry)

                mca = self.check_attr_is_id(
                    mca_id, "mca_id", MinistryCouncilAct)
                institution = self.check_attr_is_id(
                    institution_id, "institution_id", Institution)
                self.check_attr_is_int(positions, "positions")
                if not dry_run:
                    if (not mca) or (not institution):
                        continue
                    mcaip_obj = self.MODEL.objects.create(
                        mca=mca,
                        institution=institution,
                        positions=positions,
                    )
                    self.stdout.write(
                        "MCAInstitutionPositions obj  created: %s %s %s %s" %
                        (mcaip_obj.id, mca_id, institution_id, positions)
                    )
                else:
                    self.stdout.write(
                        "About to create MCAInstitutionPositions obj: %s %s %s" %
                        (mca_id, institution_id, positions)
                    )
                self.success += 1

            if self.success > 0:
                self.stdout.write(
                    "\nCreated: %d" % self.success)
            if self.failed > 0:
                self.stdout.write("Failed: %d" % self.failed)
