# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import apella.models
import django.contrib.auth.models
import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0006_require_contenttypes_0002'),
    ]

    operations = [
        migrations.CreateModel(
            name='ApellaUser',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(null=True, verbose_name='last login', blank=True)),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(help_text=b'Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=30, unique=True, error_messages={b'unique': b'A user with that username already exists.'}, validators=[django.core.validators.RegexValidator(b'^[\\w.@+-]+$', b'Enter a valid username. This value may contain only letters, numbers and @/./+/-/_ characters.', b'invalid')])),
                ('email', models.EmailField(unique=True, max_length=254, error_messages={b'unique': b'A user with that email already exists.'})),
                ('is_staff', models.BooleanField(default=False)),
                ('is_active', models.BooleanField(default=False)),
                ('activated_at', models.DateTimeField(null=True, blank=True)),
                ('email_verified', models.BooleanField(default=False)),
                ('email_verified_at', models.DateTimeField(default=None, null=True)),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now)),
                ('id_passport', models.CharField(max_length=30, blank=True)),
                ('mobile_phone_number', models.CharField(max_length=30, blank=True)),
                ('home_phone_number', models.CharField(max_length=30, blank=True)),
                ('role', models.CharField(default=b'candidate', max_length=20, choices=[['institutionmanager', 'Institution Manager'], ['candidate', 'Candidate'], ['professor', 'Professor'], ['helpdeskadmin', 'Helpdesk Admin'], ['helpdeskuser', 'Helpdesk User'], ['assistant', 'Assistant']])),
                ('login_method', models.CharField(default=b'password', max_length=20)),
                ('can_set_academic', models.BooleanField(default=False)),
                ('can_upgrade_role', models.BooleanField(default=False)),
                ('shibboleth_enabled_at', models.DateTimeField(default=None, null=True)),
                ('shibboleth_id', models.CharField(default=None, max_length=255, unique=True, null=True)),
                ('shibboleth_idp', models.CharField(max_length=255, blank=True)),
                ('shibboleth_schac_home_organization', models.CharField(max_length=255, blank=True)),
                ('shibboleth_registration_key', models.CharField(default=None, max_length=255, null=True)),
                ('shibboleth_migration_key', models.CharField(default=None, max_length=255, null=True)),
                ('remote_data', models.TextField(blank=True)),
                ('old_user_id', models.IntegerField(null=True, blank=True)),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='ApellaFile',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('source', models.CharField(max_length=30, choices=[['profile', 'Profile'], ['candidacy', 'Candidacy'], ['position', 'Position'], ['other', 'Other']])),
                ('source_id', models.IntegerField()),
                ('file_kind', models.CharField(max_length=40, choices=[['cv', 'CV'], ['cv_professor', 'CV'], ['diploma', 'Diploma'], ['publication', 'Publication'], ['id_passport', 'ID Passport'], ['electors_set_file', 'Electors Set File'], ['committee_set_file', 'Committee Set File'], ['committee_proposal', 'Committee Proposal'], ['committee_note', 'Committee Note'], ['electors_meeting_proposal', 'Electors Meeting Proposal'], ['nomination_proceedings', 'Nomination Proceedings'], ['proceedings_cover_letter', 'Proceedings Cover Letter'], ['nomination_act', 'Nomination Act'], ['revocation_decision', 'Revocation Decision'], ['failed_election_decision', 'Failed Election Decision'], ['assistant_file', 'Assistant File'], ['self_evaluation_report', 'Self Evaluation Report'], ['attachment_file', 'Attachment File'], ['registry_set_decision_file', 'Registry Set Decision File']])),
                ('file_path', models.FileField(storage=apella.models.OverwriteStorage(), max_length=255, upload_to=apella.models.generate_filename)),
                ('description', models.TextField(null=True, blank=True)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('owner', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Candidacy',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('state', models.CharField(default=b'draft', max_length=30, choices=[['draft', 'Draft'], ['posted', 'Posted'], ['cancelled', 'Cancelled']])),
                ('others_can_view', models.BooleanField(default=False)),
                ('submitted_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('code', models.CharField(max_length=255)),
                ('old_candidacy_id', models.IntegerField(null=True, blank=True)),
                ('attachment_files', models.ManyToManyField(related_name='attachment_files', to='apella.ApellaFile', blank=True)),
                ('candidate', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
                ('cv', models.ForeignKey(related_name='apella_candidacy_cv_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
                ('diplomas', models.ManyToManyField(related_name='apella_candidacy_diploma_files', to='apella.ApellaFile', blank=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Candidate',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('is_verified', models.BooleanField(default=False)),
                ('verified_at', models.DateTimeField(null=True, blank=True)),
                ('verification_pending', models.BooleanField(default=False)),
                ('verification_request', models.DateTimeField(null=True, blank=True)),
                ('is_rejected', models.BooleanField(default=False)),
                ('rejected_reason', models.TextField(null=True, blank=True)),
                ('changes_request', models.DateTimeField(null=True, blank=True)),
                ('cv', models.ForeignKey(related_name='apella_candidate_cv_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
                ('diplomas', models.ManyToManyField(related_name='apella_candidate_diploma_files', to='apella.ApellaFile', blank=True)),
                ('id_passport_file', models.ForeignKey(related_name='id_passport_file', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
                ('publications', models.ManyToManyField(related_name='apella_candidate_publication_files', to='apella.ApellaFile', blank=True)),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Department',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('dep_number', models.IntegerField(null=True, blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='ElectorParticipation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('is_regular', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='Institution',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('category', models.CharField(default=b'Institution', max_length=30, choices=[['Institution', 'Institution'], ['Research', 'Research Center']])),
                ('organization', models.URLField(blank=True)),
                ('regulatory_framework', models.URLField(blank=True)),
                ('has_shibboleth', models.BooleanField(default=False)),
                ('idp', models.CharField(max_length=255, blank=True)),
                ('schac_home_organization', models.CharField(max_length=255, blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='InstitutionManager',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('is_verified', models.BooleanField(default=False)),
                ('verified_at', models.DateTimeField(null=True, blank=True)),
                ('verification_pending', models.BooleanField(default=False)),
                ('verification_request', models.DateTimeField(null=True, blank=True)),
                ('is_rejected', models.BooleanField(default=False)),
                ('rejected_reason', models.TextField(null=True, blank=True)),
                ('changes_request', models.DateTimeField(null=True, blank=True)),
                ('authority', models.CharField(blank=True, max_length=30, null=True, choices=[['dean', 'Dean'], ['president', 'President']])),
                ('authority_full_name', models.CharField(max_length=255, null=True, blank=True)),
                ('manager_role', models.CharField(default=b'institutionmanager', max_length=20, choices=[['institutionmanager', 'Manager'], ['assistant', 'Assistant']])),
                ('sub_email', models.EmailField(max_length=254, null=True, blank=True)),
                ('sub_mobile_phone_number', models.CharField(max_length=30, null=True, blank=True)),
                ('sub_home_phone_number', models.CharField(max_length=30, null=True, blank=True)),
                ('can_create_registries', models.BooleanField(default=False)),
                ('can_create_positions', models.BooleanField(default=False)),
                ('is_secretary', models.BooleanField(default=False)),
                ('departments', models.ManyToManyField(to='apella.Department', blank=True)),
                ('institution', models.ForeignKey(to='apella.Institution', on_delete=django.db.models.deletion.PROTECT)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MultiLangFields',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('el', models.CharField(max_length=500, null=True, blank=True)),
                ('en', models.CharField(max_length=500, null=True, blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaCandidacyFileMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('candidacy_serial', models.TextField()),
                ('position_serial', models.TextField()),
                ('candidate_user_id', models.TextField()),
                ('file_id', models.TextField()),
                ('file_type', models.TextField()),
                ('file_path', models.TextField()),
                ('file_description', models.TextField()),
                ('original_name', models.TextField()),
                ('updated_at', models.DateTimeField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaCandidacyMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('candidacy_serial', models.TextField()),
                ('position_serial', models.TextField()),
                ('candidate_user_id', models.TextField()),
                ('open_to_other_candidates', models.TextField()),
                ('submitted_at', models.DateTimeField(null=True)),
                ('withdrawn_at', models.TextField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaCandidateAssistantProfessorMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('user_id', models.TextField()),
                ('account_status', models.TextField()),
                ('surname_el', models.TextField()),
                ('name_el', models.TextField()),
                ('fathername_el', models.TextField()),
                ('email', models.TextField()),
                ('institution', models.TextField()),
                ('department', models.TextField()),
                ('rank', models.TextField()),
                ('fek', models.TextField()),
                ('discipline_from_fek', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaFileMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('user_id', models.TextField()),
                ('header_id', models.TextField()),
                ('file_type', models.TextField()),
                ('file_path', models.TextField()),
                ('file_description', models.TextField()),
                ('original_name', models.TextField()),
                ('updated_at', models.DateTimeField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaInstitutionMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('institution_id', models.TextField()),
                ('institution_bylaw_url', models.TextField()),
                ('institution_organization_url', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaPositionMigrationData',
            fields=[
                ('position_serial', models.TextField(serialize=False, primary_key=True)),
                ('description', models.TextField()),
                ('title', models.TextField()),
                ('subject_id', models.TextField()),
                ('department_id', models.TextField()),
                ('manager_id', models.TextField()),
                ('subject_area_code', models.TextField()),
                ('subject_code', models.TextField()),
                ('gazette_publication_url', models.TextField()),
                ('gazette_publication_date', models.TextField()),
                ('state', models.TextField()),
                ('opening_date', models.TextField()),
                ('closing_date', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='OldApellaUserMigrationData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('migration_key', models.TextField(default=None, null=True)),
                ('user_id', models.TextField()),
                ('username', models.TextField()),
                ('permanent_auth_token', models.TextField(null=True)),
                ('passwd', models.TextField()),
                ('passwd_salt', models.TextField()),
                ('shibboleth_id', models.TextField()),
                ('role', models.TextField()),
                ('name_el', models.TextField()),
                ('surname_el', models.TextField()),
                ('fathername_el', models.TextField()),
                ('name_en', models.TextField()),
                ('surname_en', models.TextField()),
                ('fathername_en', models.TextField()),
                ('email', models.TextField()),
                ('mobile', models.TextField()),
                ('phone', models.TextField()),
                ('person_id_number', models.TextField()),
                ('is_foreign', models.TextField()),
                ('speaks_greek', models.TextField()),
                ('professor_subject_id', models.TextField()),
                ('professor_rank', models.TextField()),
                ('professor_institution_id', models.TextField()),
                ('professor_institution_freetext', models.TextField()),
                ('professor_department_id', models.TextField()),
                ('professor_appointment_gazette_url', models.TextField()),
                ('professor_subject_from_appointment', models.TextField()),
                ('professor_subject_optional_freetext', models.TextField()),
                ('professor_institution_cv_url', models.TextField()),
                ('manager_institution_id', models.TextField()),
                ('manager_appointer_authority', models.TextField()),
                ('manager_appointer_fullname', models.TextField()),
                ('manager_deputy_name_el', models.TextField()),
                ('manager_deputy_surname_el', models.TextField()),
                ('manager_deputy_fathername_el', models.TextField()),
                ('manager_deputy_name_en', models.TextField()),
                ('manager_deputy_surname_en', models.TextField()),
                ('manager_deputy_fathername_en', models.TextField()),
                ('manager_deputy_mobile', models.TextField()),
                ('manager_deputy_phone', models.TextField()),
                ('manager_deputy_email', models.TextField()),
                ('role_status', models.TextField(default=b'UNAPPROVED')),
                ('migrated_at', models.DateTimeField(null=True, blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='Position',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('code', models.CharField(max_length=255)),
                ('old_code', models.CharField(max_length=255)),
                ('title', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('discipline', models.TextField()),
                ('fek', models.URLField()),
                ('fek_posted_at', models.DateTimeField()),
                ('state', models.CharField(default=b'posted', max_length=30, choices=[['draft', 'Draft'], ['posted', 'Posted'], ['electing', 'Electing'], ['successful', 'Successful'], ['failed', 'Failed'], ['cancelled', 'Cancelled'], ['revoked', 'Revoked']])),
                ('starts_at', models.DateTimeField()),
                ('ends_at', models.DateTimeField()),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('department_dep_number', models.IntegerField()),
                ('electors_meeting_to_set_committee_date', models.DateField(null=True, blank=True)),
                ('electors_meeting_date', models.DateField(null=True, blank=True)),
                ('nomination_act_fek', models.URLField(blank=True)),
                ('assistant_files', models.ManyToManyField(related_name='position_assistant_files', to='apella.ApellaFile', blank=True)),
                ('author', models.ForeignKey(related_name='authored_positions', blank=True, to='apella.InstitutionManager')),
            ],
        ),
        migrations.CreateModel(
            name='Professor',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('is_verified', models.BooleanField(default=False)),
                ('verified_at', models.DateTimeField(null=True, blank=True)),
                ('verification_pending', models.BooleanField(default=False)),
                ('verification_request', models.DateTimeField(null=True, blank=True)),
                ('is_rejected', models.BooleanField(default=False)),
                ('rejected_reason', models.TextField(null=True, blank=True)),
                ('changes_request', models.DateTimeField(null=True, blank=True)),
                ('institution_freetext', models.CharField(max_length=255, blank=True)),
                ('rank', models.CharField(blank=True, max_length=30, choices=[['Professor', 'Professor'], ['Associate Professor', 'Associate Professor'], ['Assistant Professor', 'Assistant Professor'], ['Research Director', 'Research Director'], ['Principal Researcher', 'Principal Researcher'], ['Affiliated Researcher', 'Affiliated Researcher']])),
                ('is_foreign', models.BooleanField(default=False)),
                ('speaks_greek', models.BooleanField(default=True)),
                ('cv_url', models.URLField(blank=True)),
                ('fek', models.CharField(max_length=255, null=True, blank=True)),
                ('discipline_text', models.CharField(max_length=300, blank=True)),
                ('discipline_in_fek', models.BooleanField(default=True)),
                ('cv', models.ForeignKey(related_name='apella_professor_cv_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
                ('cv_professor', models.ForeignKey(related_name='professor_cv_file', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
                ('department', models.ForeignKey(blank=True, to='apella.Department', null=True)),
                ('diplomas', models.ManyToManyField(related_name='apella_professor_diploma_files', to='apella.ApellaFile', blank=True)),
                ('institution', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, blank=True, to='apella.Institution', null=True)),
                ('publications', models.ManyToManyField(related_name='apella_professor_publication_files', to='apella.ApellaFile', blank=True)),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProfessorRank',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('rank', models.ForeignKey(to='apella.MultiLangFields')),
            ],
        ),
        migrations.CreateModel(
            name='RegistrationToken',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('token', models.CharField(unique=True, max_length=255, blank=True)),
                ('identifier', models.CharField(max_length=255, blank=True)),
                ('data', models.TextField(blank=True)),
                ('remote_data', models.TextField(blank=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='Registry',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('type', models.CharField(default=b'internal', max_length=20, choices=[['internal', 'Internal'], ['external', 'External']])),
                ('department', models.ForeignKey(to='apella.Department', on_delete=django.db.models.deletion.PROTECT)),
                ('members', models.ManyToManyField(to='apella.Professor')),
                ('registry_set_decision_file', models.ForeignKey(related_name='registry_set_decision_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True)),
            ],
        ),
        migrations.CreateModel(
            name='School',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('institution', models.ForeignKey(to='apella.Institution', on_delete=django.db.models.deletion.PROTECT)),
                ('title', models.ForeignKey(to='apella.MultiLangFields')),
            ],
        ),
        migrations.CreateModel(
            name='Subject',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
            ],
        ),
        migrations.CreateModel(
            name='SubjectArea',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.ForeignKey(to='apella.MultiLangFields')),
            ],
        ),
        migrations.CreateModel(
            name='UserInterest',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('area', models.ManyToManyField(to='apella.SubjectArea', blank=True)),
                ('department', models.ManyToManyField(to='apella.Department', blank=True)),
                ('institution', models.ManyToManyField(to='apella.Institution', blank=True)),
                ('subject', models.ManyToManyField(to='apella.Subject', blank=True)),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='subject',
            name='area',
            field=models.ForeignKey(to='apella.SubjectArea'),
        ),
        migrations.AddField(
            model_name='subject',
            name='title',
            field=models.ForeignKey(to='apella.MultiLangFields'),
        ),
        migrations.AddField(
            model_name='position',
            name='committee',
            field=models.ManyToManyField(related_name='committee_duty', to='apella.Professor', blank=True),
        ),
        migrations.AddField(
            model_name='position',
            name='committee_note',
            field=models.ForeignKey(related_name='committee_note_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='committee_proposal',
            field=models.ForeignKey(related_name='committee_proposal_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='committee_set_file',
            field=models.ForeignKey(related_name='committee_set_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='department',
            field=models.ForeignKey(to='apella.Department', on_delete=django.db.models.deletion.PROTECT),
        ),
        migrations.AddField(
            model_name='position',
            name='elected',
            field=models.ForeignKey(related_name='elected_positions', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='electors',
            field=models.ManyToManyField(to='apella.Professor', through='apella.ElectorParticipation', blank=True),
        ),
        migrations.AddField(
            model_name='position',
            name='electors_meeting_proposal',
            field=models.ForeignKey(related_name='electors_meeting_proposal_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='electors_set_file',
            field=models.ForeignKey(related_name='electors_set_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='failed_election_decision',
            field=models.ForeignKey(related_name='failed_election_decision_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='nomination_act',
            field=models.ForeignKey(related_name='nomination_act_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='nomination_proceedings',
            field=models.ForeignKey(related_name='nomination_proceedings_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='proceedings_cover_letter',
            field=models.ForeignKey(related_name='proceedings_cover_letter_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='ranks',
            field=models.ManyToManyField(to='apella.ProfessorRank', blank=True),
        ),
        migrations.AddField(
            model_name='position',
            name='revocation_decision',
            field=models.ForeignKey(related_name='revocation_decision_files', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='second_best',
            field=models.ForeignKey(related_name='second_best_positions', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='position',
            name='subject',
            field=models.ForeignKey(to='apella.Subject', on_delete=django.db.models.deletion.PROTECT),
        ),
        migrations.AddField(
            model_name='position',
            name='subject_area',
            field=models.ForeignKey(to='apella.SubjectArea', on_delete=django.db.models.deletion.PROTECT),
        ),
        migrations.AddField(
            model_name='institutionmanager',
            name='sub_father_name',
            field=models.ForeignKey(related_name='sub_father_name', blank=True, to='apella.MultiLangFields', null=True),
        ),
        migrations.AddField(
            model_name='institutionmanager',
            name='sub_first_name',
            field=models.ForeignKey(related_name='sub_first_name', blank=True, to='apella.MultiLangFields', null=True),
        ),
        migrations.AddField(
            model_name='institutionmanager',
            name='sub_last_name',
            field=models.ForeignKey(related_name='sub_last_name', blank=True, to='apella.MultiLangFields', null=True),
        ),
        migrations.AddField(
            model_name='institutionmanager',
            name='user',
            field=models.OneToOneField(to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='institution',
            name='title',
            field=models.ForeignKey(to='apella.MultiLangFields'),
        ),
        migrations.AddField(
            model_name='electorparticipation',
            name='position',
            field=models.ForeignKey(to='apella.Position'),
        ),
        migrations.AddField(
            model_name='electorparticipation',
            name='professor',
            field=models.ForeignKey(to='apella.Professor'),
        ),
        migrations.AddField(
            model_name='department',
            name='institution',
            field=models.ForeignKey(to='apella.Institution', on_delete=django.db.models.deletion.PROTECT),
        ),
        migrations.AddField(
            model_name='department',
            name='school',
            field=models.ForeignKey(blank=True, to='apella.School', null=True),
        ),
        migrations.AddField(
            model_name='department',
            name='title',
            field=models.ForeignKey(to='apella.MultiLangFields'),
        ),
        migrations.AddField(
            model_name='candidacy',
            name='position',
            field=models.ForeignKey(to='apella.Position', on_delete=django.db.models.deletion.PROTECT),
        ),
        migrations.AddField(
            model_name='candidacy',
            name='publications',
            field=models.ManyToManyField(related_name='apella_candidacy_publication_files', to='apella.ApellaFile', blank=True),
        ),
        migrations.AddField(
            model_name='candidacy',
            name='self_evaluation_report',
            field=models.ForeignKey(related_name='self_evaluation_report', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='apella.ApellaFile', null=True),
        ),
        migrations.AddField(
            model_name='apellauser',
            name='father_name',
            field=models.ForeignKey(related_name='father_name', blank=True, to='apella.MultiLangFields', null=True),
        ),
        migrations.AddField(
            model_name='apellauser',
            name='first_name',
            field=models.ForeignKey(related_name='first_name', to='apella.MultiLangFields'),
        ),
        migrations.AddField(
            model_name='apellauser',
            name='groups',
            field=models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Group', blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', verbose_name='groups'),
        ),
        migrations.AddField(
            model_name='apellauser',
            name='last_name',
            field=models.ForeignKey(related_name='last_name', to='apella.MultiLangFields'),
        ),
        migrations.AddField(
            model_name='apellauser',
            name='user_permissions',
            field=models.ManyToManyField(related_query_name='user', related_name='user_set', to='auth.Permission', blank=True, help_text='Specific permissions for this user.', verbose_name='user permissions'),
        ),
        migrations.AlterUniqueTogether(
            name='registry',
            unique_together=set([('department', 'type')]),
        ),
    ]
